#include <stdio.h>
#include <stdlib.h>
#include "image.h"

int verbose;

int main(int argc, char **argv)
{
	int i, maxcol = 32;
	struct image img;
	char *infile = 0, *outfile = 0;

	for(i=1; i<argc; i++) {
		if(argv[i][0] == '-') {
			if(argv[i][2] != 0) {
				goto inval_arg;
			}
			switch(argv[i][1]) {
			case 'c':
				if(!argv[++i] || (maxcol = atoi(argv[i])) <= 0 || maxcol > 256) {
					fprintf(stderr, "-c must be followed by the number of colors 0 < c <= 256\n");
					return 1;
				}
				break;

			case 'v':
				verbose = 1;
				break;

			case 'h':
				printf("Usage: %s [options] <infile> <outfile>\n", argv[0]);
				printf("Options:\n");
				printf("  -c <colors>: number of colors to reduce down to (default: 32)\n");
				printf("  -v: verbose output\n");
				printf("  -h: print usage information and exit\n");
				return 0;

			default:
				goto inval_arg;
			}
		} else {
			if(!infile) {
				infile = argv[i];
			} else if(!outfile) {
				outfile = argv[i];
			} else {
inval_arg:		fprintf(stderr, "invalid argument: %s\n", argv[i]);
				return 1;
			}
		}
	}

	if(load_image(&img, infile) == -1) {
		fprintf(stderr, "failed to load image: %s\n", argv[1]);
		return 1;
	}

	quantize_image(&img, maxcol);

	if(save_image(&img, outfile) == -1) {
		fprintf(stderr, "failed to write image: %s\n", argv[2]);
		return 1;
	}

	return 0;
}
